@@ -7,6 +7,7 @@ package main
 import (
 	"encoding/base64"
 	"fmt"
+	"io"
 	"log"
 	"os"
 	"runtime"
@@ -25,24 +26,24 @@ func oxDeleteNodes(jid string, client *xmpp.Client, iqc chan xmpp.IQ) error {
 	query.CreateAttr("xmlns", nsDiscoItems)
 	nlr, err := nodeListRequest.WriteToString()
 	if err != nil {
-		return fmt.Errorf("oxDeleteNodes: failed to create node list request %w", err)
+		return fmt.Errorf("ox: delete nodes: failed to create node list request %w", err)
 	}
 	iqReply, err := sendIQ(client, iqc, jid, "get", nlr)
 	if err != nil {
-		return fmt.Errorf("oxDeleteNodes: failure with node list request iq: %w", err)
+		return fmt.Errorf("ox: delete nodes: failure with node list request iq: %w", err)
 	}
 	nodeListReply := etree.NewDocument()
 	err = nodeListReply.ReadFromBytes(iqReply.Query)
 	if err != nil {
-		return fmt.Errorf("oxDeleteNodes: failed to read node list reply iq: %w", err)
+		return fmt.Errorf("ox: delete nodes: failed to read node list reply iq: %w", err)
 	}
 	query = nodeListReply.SelectElement("query")
 	if query == nil {
-		return fmt.Errorf("error parsing iq reply")
+		return fmt.Errorf("ox: error parsing iq reply")
 	}
 	items := query.SelectElements("item")
 	if items == nil {
-		return fmt.Errorf("error parsing iq reply")
+		return fmt.Errorf("ox: error parsing iq reply")
 	}
 	for _, item := range items {
 		node := item.SelectAttr("node")
@@ -162,41 +163,41 @@ func oxImportPrivKey(jid string, privKeyLocation string, client *xmpp.Client, iq
 		if err != nil {
 			keyDecoded, err := base64.StdEncoding.DecodeString(buffer.String())
 			if err != nil {
-				return fmt.Errorf("oxImportPrivKey: failed to import private key: %w", err)
+				return fmt.Errorf("ox: import privkey: failed to import private key: %w", err)
 			}
 			key, err = crypto.NewKey(keyDecoded)
 			if err != nil {
-				return fmt.Errorf("oxImportPrivKey: failed to import private key: %w", err)
+				return fmt.Errorf("ox: import privkey: failed to import private key: %w", err)
 			}
 		}
 	}
 	entity := key.GetEntity()
 	if entity.Identities[xmppURI] == nil {
-		return fmt.Errorf("Key identity is not %s", xmppURI)
+		return fmt.Errorf("ox: key identity is not %s", xmppURI)
 	}
 	pk, err := key.GetPublicKey()
 	if err != nil {
-		return fmt.Errorf("oxImportPrivKey: failed to get public key associated to private key: %w", err)
+		return fmt.Errorf("ox: import privkey: failed to get public key associated to private key: %w", err)
 	}
 	pubKey, err := crypto.NewKey(pk)
 	if err != nil {
-		return fmt.Errorf("oxImportPrivKey: failed to get public key associated to private key: %w", err)
+		return fmt.Errorf("ox: import privkey: failed to get public key associated to private key: %w", err)
 	}
 	fingerprint := strings.ToUpper(pubKey.GetFingerprint())
 	_, err = oxRecvPublicKeys(client, iqc, jid, fingerprint)
 	if err != nil {
 		err = oxPublishPubKey(jid, client, iqc, pubKey)
 		if err != nil {
-			return fmt.Errorf("oxImportPrivKey: failed to publish public key: %w", err)
+			return fmt.Errorf("ox: import privkey: failed to publish public key: %w", err)
 		}
 	}
 	location, err := oxGetPrivKeyLoc(jid)
 	if err != nil {
-		return fmt.Errorf("oxImportPrivKey: failed to determine private key location: %w", err)
+		return fmt.Errorf("ox: import privkey: failed to determine private key location: %w", err)
 	}
 	keySerialized, err := key.Serialize()
 	if err != nil {
-		return fmt.Errorf("oxImportPrivKey: failed to serialize private key: %w", err)
+		return fmt.Errorf("ox: import privkey: failed to serialize private key: %w", err)
 	}
 	err = oxStoreKey(location,
 		base64.StdEncoding.EncodeToString(keySerialized))
@@ -214,7 +215,7 @@ func oxImportPrivKey(jid string, privKeyLocation string, client *xmpp.Client, iq
 	}
 	err = oxPublishPubKey(jid, client, iqc, pubKey)
 	if err != nil {
-		return fmt.Errorf("oxImportPrivKey: failed to publish public key: %w", err)
+		return fmt.Errorf("ox: import privkey: failed to publish public key: %w", err)
 	}
 	return nil
 }
@@ -224,7 +225,7 @@ func oxPublishPubKey(jid string, client *xmpp.Client, iqc chan xmpp.IQ, pubKey *
 	fingerprint := strings.ToUpper(pubKey.GetFingerprint())
 	keySerialized, err := pubKey.Serialize()
 	if err != nil {
-		return fmt.Errorf("oxPublishPubKey: failed to serialize pubkey: %w", err)
+		return fmt.Errorf("ox: publish pubkey: failed to serialize pubkey: %w", err)
 	}
 	pubKeyBase64 := base64.StdEncoding.EncodeToString(keySerialized)
 	root := etree.NewDocument()
@@ -254,26 +255,26 @@ func oxPublishPubKey(jid string, client *xmpp.Client, iqc chan xmpp.IQ, pubKey *
 	value.CreateText("open")
 	xmlstring, err := root.WriteToString()
 	if err != nil {
-		return fmt.Errorf("oxPublishPubKey: failed to create publish public key iq xml: %w", err)
+		return fmt.Errorf("ox: publish pubkey: failed to create publish public key iq xml: %w", err)
 	}
 	iqReply, err := sendIQ(client, iqc, jid, "set", xmlstring)
 	if err != nil {
-		return fmt.Errorf("oxPublishPubKey: iq failure publishing public key: %w", err)
+		return fmt.Errorf("ox: publish pubkey: iq failure publishing public key: %w", err)
 	}
 	if iqReply.Type != strResult {
-		return fmt.Errorf("error while publishing public key")
+		return fmt.Errorf("ox: error while publishing public key")
 	}
 	ownPubKeyRingFromPubsub, err := oxRecvPublicKeys(client, iqc, jid, fingerprint)
 	if err != nil {
-		return fmt.Errorf("couldn't successfully verify public key upload")
+		return fmt.Errorf("ox: couldn't successfully verify public key upload")
 	}
 	ownPubKeyFromPubsub := ownPubKeyRingFromPubsub.GetKeys()[0]
 	ownPubKeyFromPubsubSerialized, err := ownPubKeyFromPubsub.Serialize()
 	if err != nil {
-		return fmt.Errorf("couldn't successfully verify public key upload")
+		return fmt.Errorf("ox: couldn't successfully verify public key upload")
 	}
 	if pubKeyBase64 != base64.StdEncoding.EncodeToString(ownPubKeyFromPubsubSerialized) {
-		return fmt.Errorf("couldn't successfully verify public key upload")
+		return fmt.Errorf("ox: couldn't successfully verify public key upload")
 	}
 	root = etree.NewDocument()
 	root.WriteSettings.AttrSingleQuote = true
@@ -302,32 +303,32 @@ func oxPublishPubKey(jid string, client *xmpp.Client, iqc chan xmpp.IQ, pubKey *
 	value.CreateText("open")
 	xmlstring, err = root.WriteToString()
 	if err != nil {
-		return fmt.Errorf("oxPublishPubKey: failed to create xml for iq to publish public key list: %w", err)
+		return fmt.Errorf("ox: publish pubkey: failed to create xml for iq to publish public key list: %w", err)
 	}
 	iqReply, err = sendIQ(client, iqc, jid, "set", xmlstring)
 	if err != nil {
-		return fmt.Errorf("oxPublishPubKey: iq failure publishing public key list: %w", err)
+		return fmt.Errorf("ox: publish pubkey: iq failure publishing public key list: %w", err)
 	}
 	if iqReply.Type != strResult {
-		return fmt.Errorf("couldn't publish public key list")
+		return fmt.Errorf("ox: couldn't publish public key list")
 	}
 	return nil
 }
 
 func oxGetPrivKeyLoc(jid string) (string, error) {
-	dataDir, err := getDataPath(strings.Replace(strings.Replace(jid, "@", "_at_", -1), ".", "_", -1))
+	dataDir, err := getDataPath(fsFriendlyJid(jid), true)
 	if err != nil {
-		return strError, fmt.Errorf("oxGetPrivKeyLoc: %w", err)
+		return strError, fmt.Errorf("ox: get privkey location: %w", err)
 	}
-	oldDataDir, err := getDataPath("oxprivkeys/")
+	oldDataDir, err := getDataPath("oxprivkeys/", false)
 	if err != nil {
-		return strError, fmt.Errorf("oxGetPrivKeyLoc: %w", err)
+		return strError, fmt.Errorf("ox: get privkey location: %w", err)
 	}
 	// TODO: Remove handling of oldDataFile in a later version when it's very likely that there are no
 	// more versions in use using the oldDataFile (<0.8.3).
 	oldDataFile := oldDataDir + base64.StdEncoding.EncodeToString([]byte(jid))
-	oldDataFile2 := oldDataDir + strings.Replace(jid, "@", "_at_", -1)
-	oldDataFile3 := oldDataDir + strings.Replace(strings.Replace(jid, "@", "_at_", -1), ".", "_", -1)
+	oldDataFile2 := oldDataDir + strings.ReplaceAll(jid, "@", "_at_")
+	oldDataFile3 := oldDataDir + fsFriendlyJid(jid)
 	dataFile := dataDir + "oxprivkey"
 	if _, err := os.Stat(oldDataFile); err == nil {
 		err := os.Rename(oldDataFile, dataFile)
@@ -347,13 +348,24 @@ func oxGetPrivKeyLoc(jid string) (string, error) {
 			return dataFile, err
 		}
 	}
+	dir, err := os.Open(oldDataDir)
+	if err == nil {
+		_, err = dir.ReadDir(1)
+		// Delete old data dir if empty.
+		if err == io.EOF {
+			err = os.Remove(oldDataDir)
+			if err != nil {
+				fmt.Printf("oxGetPrivKeyLoc: failed to delete old private key location: %v\n", err)
+			}
+		}
+	}
 	return dataFile, nil
 }
 
 func oxGetPubKeyLoc(fingerprint string) (string, error) {
-	dataDir, err := getDataPath("oxpubkeys/")
+	dataDir, err := getDataPath("oxpubkeys/", true)
 	if err != nil {
-		return strError, fmt.Errorf("oxGetPubKeyLoc: %w", err)
+		return strError, fmt.Errorf("ox: get pubkey location: %w", err)
 	}
 	dataFile := dataDir + fingerprint
 	return dataFile, nil
@@ -371,27 +383,27 @@ func oxGetPrivKey(jid string, passphrase string) (*crypto.Key, error) {
 	keyString := keyBuffer.String()
 	decodedPrivKey, err := base64.StdEncoding.DecodeString(keyString)
 	if err != nil {
-		return nil, fmt.Errorf("oxGetPrivKey: failed to decode private key: %w", err)
+		return nil, fmt.Errorf("ox: get privkey: failed to decode private key: %w", err)
 	}
 	key, err := crypto.NewKey(decodedPrivKey)
 	if err != nil {
-		return nil, fmt.Errorf("oxGetPrivKey: failed to decode private key: %w", err)
+		return nil, fmt.Errorf("ox: get privkey: failed to decode private key: %w", err)
 	}
 	if passphrase != "" {
 		key, err = key.Unlock([]byte(passphrase))
 		if err != nil {
-			log.Fatal("Ox: couldn't unlock private key.")
+			log.Fatal("ox: couldn't unlock private key.")
 		}
 	}
 	isLocked, err := key.IsLocked()
 	if err != nil {
-		return nil, fmt.Errorf("oxGetPrivKey: failed to check whether private key is locked: %w", err)
+		return nil, fmt.Errorf("ox: get privkey: failed to check whether private key is locked: %w", err)
 	}
 	if isLocked {
-		log.Fatal("Ox: private key is locked.")
+		log.Fatal("ox: private key is locked.")
 	}
 	if key.IsExpired() {
-		return nil, fmt.Errorf("Ox: private key is expired: %s", key.GetFingerprint())
+		return nil, fmt.Errorf("ox: private key is expired: %s", key.GetFingerprint())
 	}
 	return key, nil
 }
@@ -400,7 +412,7 @@ func oxStoreKey(location string, key string) error {
 	var file *os.File
 	file, err := os.Create(location)
 	if err != nil {
-		return fmt.Errorf("oxStoreKey: failed to create key location: %w", err)
+		return fmt.Errorf("ox: store key: failed to create key location: %w", err)
 	}
 	if runtime.GOOS != "windows" {
 		_ = file.Chmod(os.FileMode(defaultFileRights))
@@ -409,7 +421,7 @@ func oxStoreKey(location string, key string) error {
 	}
 	_, err = file.Write([]byte(key))
 	if err != nil {
-		return fmt.Errorf("oxStoreKey: failed to write key to file: %w", err)
+		return fmt.Errorf("ox: store key: failed to write key to file: %w", err)
 	}
 	err = file.Close()
 	if err != nil {
@@ -424,21 +436,21 @@ func oxGenPrivKey(jid string, client *xmpp.Client, iqc chan xmpp.IQ,
 	xmppURI := "xmpp:" + jid
 	key, err := crypto.GenerateKey(xmppURI, "", keyType, defaultRSABits)
 	if err != nil {
-		return fmt.Errorf("oxGenPrivKey: failed to generate private key: %w", err)
+		return fmt.Errorf("ox: generate privkey: failed to generate private key: %w", err)
 	}
 	if passphrase != "" {
 		key, err = key.Lock([]byte(passphrase))
 		if err != nil {
-			return fmt.Errorf("oxGenPrivKey: failed to lock key with passphrase: %w", err)
+			return fmt.Errorf("ox: generate privkey: failed to lock key with passphrase: %w", err)
 		}
 	}
 	keySerialized, err := key.Serialize()
 	if err != nil {
-		return fmt.Errorf("oxGenPrivKey: failed to serialize private key: %w", err)
+		return fmt.Errorf("ox: generate privkey: failed to serialize private key: %w", err)
 	}
 	location, err := oxGetPrivKeyLoc(jid)
 	if err != nil {
-		return fmt.Errorf("oxGenPrivKey: failed to get private key location: %w", err)
+		return fmt.Errorf("ox: generate privkey: failed to get private key location: %w", err)
 	}
 	err = oxStoreKey(location,
 		base64.StdEncoding.EncodeToString(keySerialized))
@@ -447,15 +459,15 @@ func oxGenPrivKey(jid string, client *xmpp.Client, iqc chan xmpp.IQ,
 	}
 	decodedPubKey, err := key.GetPublicKey()
 	if err != nil {
-		return fmt.Errorf("oxGenPrivKey: failed to decode public key: %w", err)
+		return fmt.Errorf("ox: generate privkey: failed to decode public key: %w", err)
 	}
 	pubKey, err := crypto.NewKey(decodedPubKey)
 	if err != nil {
-		return fmt.Errorf("oxGenPrivKey: failed to decode public key: %w", err)
+		return fmt.Errorf("ox: generate privkey: failed to decode public key: %w", err)
 	}
 	err = oxPublishPubKey(jid, client, iqc, pubKey)
 	if err != nil {
-		return fmt.Errorf("oxGenPrivKey: failed to publish public key: %w", err)
+		return fmt.Errorf("ox: generate privkey: failed to publish public key: %w", err)
 	}
 	return nil
 }
@@ -470,24 +482,24 @@ func oxRecvPublicKeys(client *xmpp.Client, iqc chan xmpp.IQ, recipient string, f
 	opkrPsItems.CreateAttr("max_items", "1")
 	opkrString, err := opkr.WriteToString()
 	if err != nil {
-		return nil, fmt.Errorf("oxRecvPublicKeys: failed to generate xml for public key request: %w", err)
+		return nil, fmt.Errorf("ox: receive public keys: failed to generate xml for public key request: %w", err)
 	}
 	oxPublicKey, err := sendIQ(client, iqc, recipient, "get", opkrString)
 	if err != nil {
-		return nil, fmt.Errorf("oxRecvPublicKeys: iq error requesting public keys: %w", err)
+		return nil, fmt.Errorf("ox: receive public keys: iq error requesting public keys: %w", err)
 	}
 	if oxPublicKey.Type != strResult {
-		return nil, fmt.Errorf("error while requesting public key for %s",
+		return nil, fmt.Errorf("ox: error while requesting public key for %s",
 			recipient)
 	}
 	oxPublicKeyXML := etree.NewDocument()
 	err = oxPublicKeyXML.ReadFromBytes(oxPublicKey.Query)
 	if err != nil {
-		return nil, fmt.Errorf("oxRecvPublicKeys: failed parsing iq reply to public key request: %w", err)
+		return nil, fmt.Errorf("ox: receive public keys: failed parsing iq reply to public key request: %w", err)
 	}
 	keyring, err := crypto.NewKeyRing(nil)
 	if err != nil {
-		return nil, fmt.Errorf("oxRecvPublicKeys: failed reading public key: %w", err)
+		return nil, fmt.Errorf("ox: receive public keys: failed reading public key: %w", err)
 	}
 	oxPublicKeyXMLPubsub := oxPublicKeyXML.SelectElement("pubsub")
 	if oxPublicKeyXMLPubsub == nil {
@@ -509,18 +521,18 @@ func oxRecvPublicKeys(client *xmpp.Client, iqc chan xmpp.IQ, recipient string, f
 		}
 		decodedPubKey, err := base64.StdEncoding.DecodeString(data.Text())
 		if err != nil {
-			return nil, fmt.Errorf("oxRecvPublicKeys: failed to decode public key: %w", err)
+			return nil, fmt.Errorf("ox: receive public keys: failed to decode public key: %w", err)
 		}
 		key, err := crypto.NewKey(decodedPubKey)
 		if err != nil {
-			return nil, fmt.Errorf("oxRecvPublicKeys: failed to decode public key: %w", err)
+			return nil, fmt.Errorf("ox: receive public keys: failed to decode public key: %w", err)
 		}
 		if key.IsExpired() {
-			return nil, fmt.Errorf("Key is expired: %s", fingerprint)
+			return nil, fmt.Errorf("ox: key is expired: %s", fingerprint)
 		}
 		err = keyring.AddKey(key)
 		if err != nil {
-			return nil, fmt.Errorf("oxRecvPublicKeys: failed adding public key to keyring: %w", err)
+			return nil, fmt.Errorf("ox: receive public keys: failed adding public key to keyring: %w", err)
 		}
 	}
 	return keyring, nil
@@ -529,7 +541,7 @@ func oxRecvPublicKeys(client *xmpp.Client, iqc chan xmpp.IQ, recipient string, f
 func oxGetPublicKeyRing(client *xmpp.Client, iqc chan xmpp.IQ, recipient string) (*crypto.KeyRing, error) {
 	publicKeyRing, err := crypto.NewKeyRing(nil)
 	if err != nil {
-		return nil, fmt.Errorf("oxGetPublicKeyRing: failed to create a new keyring: %w", err)
+		return nil, fmt.Errorf("ox: get public keyring: failed to create a new keyring: %w", err)
 	}
 
 	oxPubKeyListReq := etree.NewDocument()
@@ -548,19 +560,19 @@ func oxGetPublicKeyRing(client *xmpp.Client, iqc chan xmpp.IQ, recipient string)
 		log.Fatal(err)
 	}
 	if oxPublicKeyList.Type != strResult {
-		return nil, fmt.Errorf("error while requesting public openpgp keys for %s",
+		return nil, fmt.Errorf("ox: error while requesting public openpgp keys for %s",
 			recipient)
 	}
 	oxPubKeyListXML := etree.NewDocument()
 	err = oxPubKeyListXML.ReadFromBytes(oxPublicKeyList.Query)
 	if err != nil {
-		return nil, fmt.Errorf("oxGetPublicKeyRing: failed to parse answer to public key list request: %w", err)
+		return nil, fmt.Errorf("ox: get public keyring: failed to parse answer to public key list request: %w", err)
 	}
 
 	pubKeyRingID := "none"
 	newestKey, err := time.Parse(time.RFC3339, "1900-01-01T00:00:00Z")
 	if err != nil {
-		return nil, fmt.Errorf("oxGetPublicKeyRing: failed to set time for newest key to 1900-01-01: %w", err)
+		return nil, fmt.Errorf("ox: get public keyring: failed to set time for newest key to 1900-01-01: %w", err)
 	}
 
 	oxPubKeyListXMLPubsub := oxPubKeyListXML.SelectElement("pubsub")
@@ -591,7 +603,7 @@ func oxGetPublicKeyRing(client *xmpp.Client, iqc chan xmpp.IQ, recipient string)
 		}
 		keyDate, err := time.Parse(time.RFC3339, date.Value)
 		if err != nil {
-			return nil, fmt.Errorf("oxGetPublicKeyRing: failed to parse time stamp for key: %w", err)
+			return nil, fmt.Errorf("ox: get public keyring: failed to parse time stamp for key: %w", err)
 		}
 		if keyDate.After(newestKey) {
 			newestKey = keyDate
@@ -599,12 +611,12 @@ func oxGetPublicKeyRing(client *xmpp.Client, iqc chan xmpp.IQ, recipient string)
 		}
 	}
 	if pubKeyRingID == "none" {
-		return nil, fmt.Errorf("server didn't provide public key fingerprints for %s", recipient)
+		return nil, fmt.Errorf("ox: server didn't provide public key fingerprints for %s", recipient)
 	}
 
 	pubKeyRingLocation, err := oxGetPubKeyLoc(pubKeyRingID)
 	if err != nil {
-		return nil, fmt.Errorf("oxGetPublicKeyRing: failed to get public key ring location: %w", err)
+		return nil, fmt.Errorf("ox: get public keyring: failed to get public key ring location: %w", err)
 	}
 
 	pubKeyReadXML := etree.NewDocument()
@@ -614,26 +626,26 @@ func oxGetPublicKeyRing(client *xmpp.Client, iqc chan xmpp.IQ, recipient string)
 		if date != nil {
 			savedKeysDate, err := time.Parse(time.RFC3339, date.Text())
 			if err != nil {
-				return nil, fmt.Errorf("oxGetPublicKeyRing: failed to parse time for saved key: %w", err)
+				return nil, fmt.Errorf("ox: get public keyring: failed to parse time for saved key: %w", err)
 			}
 			if !savedKeysDate.Before(newestKey) {
 				pubKeys := pubKeyReadXML.SelectElements("pubkey")
 				if pubKeys == nil {
-					return nil, fmt.Errorf("couldn't read public keys from cache")
+					return nil, fmt.Errorf("ox: couldn't read public keys from cache")
 				}
 				for _, r := range pubKeys {
 					keyByte, err := base64.StdEncoding.DecodeString(r.Text())
 					if err != nil {
-						return nil, fmt.Errorf("oxGetPublicKeyRing: failed to decode saved key: %w", err)
+						return nil, fmt.Errorf("ox: get public keyring: failed to decode saved key: %w", err)
 					}
 					key, err := crypto.NewKey(keyByte)
 					if err != nil {
-						return nil, fmt.Errorf("oxGetPublicKeyRing: failed to parse saved key: %w", err)
+						return nil, fmt.Errorf("ox: get public keyring: failed to parse saved key: %w", err)
 					}
 					if !key.IsExpired() {
 						err = publicKeyRing.AddKey(key)
 						if err != nil {
-							return nil, fmt.Errorf("oxGetPublicKeyRing: failed to add key to public keyring: %w", err)
+							return nil, fmt.Errorf("ox: get public keyring: failed to add key to public keyring: %w", err)
 						}
 					}
 				}
@@ -645,7 +657,7 @@ func oxGetPublicKeyRing(client *xmpp.Client, iqc chan xmpp.IQ, recipient string)
 	}
 	pubKeyRing, err := oxRecvPublicKeys(client, iqc, recipient, pubKeyRingID)
 	if err != nil {
-		return nil, fmt.Errorf("oxGetPublicKeyRing: failed to get public keyring: %w", err)
+		return nil, fmt.Errorf("ox: get public keyring: failed to get public keyring: %w", err)
 	}
 	pubKeySaveXML := etree.NewDocument()
 	date := pubKeySaveXML.CreateElement("date")
@@ -653,25 +665,25 @@ func oxGetPublicKeyRing(client *xmpp.Client, iqc chan xmpp.IQ, recipient string)
 	for _, key := range pubKeyRing.GetKeys() {
 		keySerialized, err := key.Serialize()
 		if err != nil {
-			return nil, fmt.Errorf("oxGetPublicKeyRing: failed to serialize key: %w", err)
+			return nil, fmt.Errorf("ox: get public keyring: failed to serialize key: %w", err)
 		}
 		saveKey := pubKeySaveXML.CreateElement("pubkey")
 		saveKey.SetText(base64.StdEncoding.EncodeToString(keySerialized))
 	}
 	err = pubKeySaveXML.WriteToFile(pubKeyRingLocation)
 	if err != nil {
-		return nil, fmt.Errorf("oxGetPublicKeyRing: failed to create xml for saving public key: %w", err)
+		return nil, fmt.Errorf("ox: get public keyring: failed to create xml for saving public key: %w", err)
 	}
 	return pubKeyRing, nil
 }
 
-func oxEncrypt(client *xmpp.Client, oxPrivKey *crypto.Key, recipient string, keyRing *crypto.KeyRing, message string, subject string) (string, error) {
+func oxEncrypt(client *xmpp.Client, oxPrivKey *crypto.Key, recipient string, keyRing crypto.KeyRing, message string, subject string) (string, error) {
 	if message == "" {
 		return "", nil
 	}
 	privKeyRing, err := crypto.NewKeyRing(oxPrivKey)
 	if err != nil {
-		return strError, fmt.Errorf("oxEncrypt: failed to create private keyring: %w", err)
+		return strError, fmt.Errorf("ox: encrypt: failed to create private keyring: %w", err)
 	}
 	ownJid := strings.Split(client.JID(), "/")[0]
 	if recipient != ownJid {
@@ -701,12 +713,12 @@ func oxEncrypt(client *xmpp.Client, oxPrivKey *crypto.Key, recipient string, key
 	oxCryptMessageScPayloadBody.CreateText(message)
 	ocm, err := oxCryptMessage.WriteToString()
 	if err != nil {
-		return strError, fmt.Errorf("oxEncrypt: failed to create xml for ox crypt message: %w", err)
+		return strError, fmt.Errorf("ox: encrypt: failed to create xml for ox crypt message: %w", err)
 	}
 	plainMessage := crypto.NewPlainMessage([]byte(ocm))
 	pgpMessage, err := keyRing.Encrypt(plainMessage, privKeyRing)
 	if err != nil {
-		return strError, fmt.Errorf("oxEncrypt: failed to create pgp message: %w", err)
+		return strError, fmt.Errorf("ox: encrypt: failed to create pgp message: %w", err)
 	}
 	om := etree.NewDocument()
 	om.WriteSettings.AttrSingleQuote = true
@@ -725,7 +737,7 @@ func oxEncrypt(client *xmpp.Client, oxPrivKey *crypto.Key, recipient string, key
 	omMessageBody.CreateText(oxAltBody)
 	oms, err := om.WriteToString()
 	if err != nil {
-		return strError, fmt.Errorf("oxEncrypt: failed to create xml for ox message: %w", err)
+		return strError, fmt.Errorf("ox: encrypt: failed to create xml for ox message: %w", err)
 	}
 
 	return oms, nil
